@@ -4,28 +4,42 @@ import json
 from datetime import datetime
 import graphyte
 import consul
-
+from jsonformatter import JsonFormatter
 from cloudevents.sdk.event import v03
-
-
-
+import os
+import logging
+import uuid
+from datetime import datetime
 
 class ApplicationConfigurator():
 
-    def get(self,consul_host,consul_port,app_name):
+    def get(self,config_key):
         config = {}
         try:
-            c = consul.Consul(host=consul_host, port=consul_port)
+            c = consul.Consul(host=os.environ['CONSUL_HOST'], port=os.environ['CONSUL_PORT'])
             index = None
-            index, data = c.kv.get(app_name, index=None)
+            index, data = c.kv.get(config_key, index=None)
             the_json = data['Value'].decode("utf-8")
             config = json.loads(the_json)
         except Exception as ex:
-            print('Exception in publishing message')
+            print('Exception in getting key')
             print(ex)
 
         return config
 
+    def put(self,config_key, config_value):
+        config = {}
+        try:
+            c = consul.Consul(host=os.environ['CONSUL_HOST'], port=os.environ['CONSUL_PORT'])
+            index = None
+            c.kv.put(config_key, config_value)
+        except Exception as ex:
+            print('Exception in getting key')
+            print(ex)
+
+        return config
+
+
 class KafkaConfig(object):
     def __init__(self, kafka_brokers, json=False):
         self.json = json
@@ -48,12 +62,23 @@ class KafkaConfig(object):
 
 class FerrisKafkaLoggingHandler(StreamHandler):
 
-    def __init__(self, broker, topic):
+    def __init__(self,topic):
         StreamHandler.__init__(self)
-        self.broker = broker
+        self.broker = os.environ['KAFKA_BOOTSTRAP_SERVER'] + ':' + os.environ['KAFKA_PORT']
         self.topic = topic
         # Kafka Broker Configuration
-        self.kafka_broker = KafkaConfig(broker)
+        self.kafka_broker = KafkaConfig(self.broker)
+
+        STRING_FORMAT = '''{
+        "Levelname":       "levelname",
+        "Name":            "name",
+        "Asctime":         "asctime",
+        "Message":         "message"
+        }'''
+
+        formatter =  JsonFormatter(STRING_FORMAT)
+        self.setFormatter(formatter)
+
     def emit(self, record):
         msg = self.format(record)
         self.kafka_broker.send(msg, self.topic)
@@ -77,52 +102,32 @@ class MetricMessage(object):
 
 class MetricsAPI:
 
-    def __init__(self):
-        #print("in init")
-        pass
 
+    def __init__(self, topic='ferris.metrics'):
+        self.broker = os.environ['KAFKA_BOOTSTRAP_SERVER'] + ':' + os.environ['KAFKA_PORT']
+        self.topic = topic
+        # Kafka Broker Configuration
+        self.kafka_broker = KafkaConfig(self.broker)
+        print('metrics init called')
 
-    def send(self,graphyte_host,metric_message:MetricMessage):
+    def send(self,metric_message:MetricMessage):
         try:
-            graphyte.init(graphyte_host, prefix='ai.ferris')
-            graphyte.send(metric_message.metric_key, metric_message.metric_value)
+            self.kafka_broker.send(metric_message.toJSON(), self.topic)
         except Exception as ex:
             print('Exception in publishing message')
             print(ex)
-        pass
-
-class TaskTrackerMessage(object):
-    def __init__(self, job_name,job_key,instance_id,job_status,status_message,update_time, correlation_id):  
-        self.job_name = job_name
-        self.job_key = job_key
-        self.instance_id = instance_id
-        self.job_status = job_status
-        self.status_message = status_message
-        self.update_time = update_time
-        self.correlation_id = correlation_id
-    def toJSON(self):
-        return json.dumps(self, default=lambda o: o.__dict__, 
-            sort_keys=True, indent=4)
-
-class TaskTrackerAPI():
-
-    def __init__(self, broker, topic='ferris.jobtracker'):
-        self.broker = broker
-        self.topic = topic
-        # Kafka Broker Configuration
-        self.kafka_broker = KafkaConfig(broker)
-    def send(self, record:TaskTrackerMessage):
-        self.kafka_broker.send(record.toJSON(), self.topic)
 
 
 class CloudEventsAPI():
 
-    def __init__(self, broker, topic='ferris.cloudevents'):
-        self.broker = broker
+    def __init__(self, topic='ferris.cloudevents'):
+        self.broker = os.environ['KAFKA_BOOTSTRAP_SERVER'] + ':' + os.environ['KAFKA_PORT']
         self.topic = topic
         # Kafka Broker Configuration
         self.kafka_broker = KafkaConfig(broker)
     def send(self, event):
+        event.SetEventID(uuid.uuid1().hex)
+        date_time = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
+        event.SetEventTime(date_time)
         s = json.dumps(event.Properties())
         self.kafka_broker.send(s, self.topic)
-
